@@ -40,19 +40,19 @@ class TransformersFastClsTask(TransformersFastTask):
                                   train_file=self._args.train_file,
                                   val_file=self._args.eval_file,
                                   label_file=self._args.labels_file,
-                                  text_col='text',
-                                  label_col='label',
-                                  batch_size_per_gpu=16,
-                                  max_seq_length=512,
+                                  text_col=self._args.text_col,
+                                  label_col=self._args.label_col,
+                                  batch_size_per_gpu=self._args.batch_size_per_gpu,
+                                  max_seq_length=self._args.max_seq_length,
                                   multi_gpu=True,
-                                  multi_label=False,
+                                  multi_label=self._args.multi_label,
                                   model_type='bert')
         device = torch.device('cuda')
         learner = BertLearner.from_pretrained_model(databunch, self._model_path, metrics=self.metrics(),
                                                     device=device, logger=log, output_dir=self._output_dir,
                                                     finetuned_wgts_path=None, warmup_steps=5,
-                                                    multi_gpu=True, is_fp16=False,
-                                                    multi_label=False, logging_steps=0)
+                                                    multi_gpu=True, is_fp16=self._args.fp16,
+                                                    multi_label=self._args.multi_label, logging_steps=0)
         learner.fit(self._args.num_train_epochs, self._args.learning_rate, validate=True)
         learner.validate()
 
