@@ -13,7 +13,7 @@ from ..model import ModelMode, task_model
 from ..model.model_args import ModelArguments
 from ..task.task_args import TaskArguments, parse_tasks_args
 from ..train.trainer import Trainer
-from ..train.trainer_utils import PredictionOutput, EvalPrediction
+from ..train.trainer_utils import PredictionOutput, EvalPrediction, InputExample
 from ..train.training_args import TrainingArguments
 from ..data import DataArguments, TaskDataset, DataProcessor
 from ..transformersx_base import aiutils, log, join_path
@@ -275,8 +275,16 @@ class TransformerTask:
         results = self._taskTrainer.eval()
         return results
 
-    def single_predict(self, *input):
-        return self._taskModel.model(*input)
+    def single_predict(self, example: InputExample):
+        input_ids = torch.tensor(self._taskModel.tokenizer.encode_plus(
+            (example.text_a, example.text_b),
+            max_length=self.task_args.data_args.max_seq_length,
+            pad_to_max_length=True
+        )).unsqueeze(0)  # Batch size 1
+
+        input_ids.to(self.task_args.training_args.device)
+
+        return self._taskModel.model(input_ids)[0]
 
     def predict(self, data_processor=None) -> PredictionOutput:
         dataset = TaskDataset(self.task_args.data_args,
